function plot_schlogl(X0)
%
% Compute the most sensitive parameters and the most sensitive directions
% of the Schlogl model when it has two shallow wells. For shallow wells the
% numerical results matches very well with the analytical results independently
% of the initial data.
%
% (c) Math & Stat, Umass, Amherst, 2014

NoI = 1;

N = 300; % maximum number of molecules
n = 0:N;
Omega = 15; % volume of the system (behaves like inverse temperature in IPS)

% reaction rates
k1A = 3;
k2 = 1;
k3B = 2;
k4 = 3.5;
theta = [k1A, k2, k3B, k4];

% directions
eps0 = 0.05;
epsilon = eps0*[eye(4); -eye(4)];
[L, d] = size(epsilon);

dir_idx = [1,5,2,6,3,7,4,8];

% find the most sensitive directions
RER = zeros(1, L);
FIM = zeros(d, d);
for i = 1:NoI
    [RER_tmp, RER_exact, FIM_tmp, FIM_exact] = comp_RER_FIM_ssaSchlolg(X0, Omega, N, theta, epsilon);
    
    RER = RER + RER_tmp/NoI;
    FIM = FIM + FIM_tmp/NoI;
end

[RER_des, idx] = sort(RER, 'descend');


% based on the most/less sens. directions, see how much the inv. measure is
% changed.
[p_exact, p_approx, p_hist, p_exact_per, p_hist_per] = invMeasure_change(X0, Omega, N, theta, epsilon);

% plot the invariant measures
figure(1);
plot(n, p_exact, 'k');hold on;
plot(n, p_exact_per(idx(1),:), '-.r');
plot(n, p_exact_per(idx(L),:), '--g');hold off;
xlim([0 160])
ylim([0 0.06])
xlabel('Number of X molecules');
ylabel('Invariant measure');
legend('Reference', 'Most sensitive param.', 'Least sensitive param.');