function rate = reaction_rate(data, reaction)  % 'reaction' is the index of reaction
% Computes the rate of the reaction.
%
%  ---- INPUT PARAMETERS ----
%   data: data structure array
%
%   data.X: current population of the system, [Nx1]
%   data.con: value of reaction constants, [Kx1]
%   data.stoichio: stoichiometric matrix, [Mx4]
%   data.cm_rea: connectivity matrix for the reactions, [Mx4]
%
%   reaction: index of reaction whose rate is computed, [1x1]
%
% ---- OUTPUT PARAMETERS ----
%   rate : rate of the reaction, [1x1]
%
% (c) Math & Stat, Umass, Amherst, 2014

rate = get_rate(reaction, data);

for j=1:2
    species = data.cm_rea(reaction, j);    

    % check if species is not NULL (species==1)
    if species > 1       
    
        % check if there are enough elements of species
        if data.X(species) < abs(data.stoichio(reaction, j))  % data.X is the initial pop and check if pop now is enough to perform the reaction
            rate = 0;
        end
    end  
end

