function test_isap_Schlogl
%
% Simulates and performs path-wise sensitivity analysis for the Schlogl reaction
% network. The system at this particular parameter regime admits oscillations.
%
% (c) Math & Stat, Umass, Amherst, 2014

% files and directories
dname = 'examples/Schlogl/'; % directory with the reaction network
fname = [dname 'input_files/Schlogl']; % file with the reactions

% create auxiliary files, if necessary
exCM = dir([fname '_connectivity.txt']);
if isempty(exCM) % if connectivity matrix does not exist, create it
    rxn2csm([fname '.txt']);
end

% initialize data
% data = initialization_lin(fname);  % for linear-scale sensitivity analysis
data = initialization_log(fname); % for log-scale sensitivity analysis

data.T = 200; % final time
data.NoJ = 10^6; % maximum number of jumps

data.NoS = 5; % number of repeated simulations
dt = .1; % sampling frequency in time
data.ti = dt : dt : data.T; % sampling time instants
data.tau = 0.05; % time-step for CLE

% simulate the reaction network and save the species time-series
sim_rxn(data, [dname 'data/'], 'CLE');


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%    PATHWISE SENSITIVITY ANALYSIS    %%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% create perturbation vectors
eps0 = .1; % 10% parameter perturbation
pert_vec = diag(eps0*data.con);
pert_vec = [pert_vec; -pert_vec]; % +10% and -10% perturbation

data.eps0 = eps0;
data.pert_vec = pert_vec;

% compute PFIM and/or RER
%PFIM = compute_PFIM_RER(data, dname);
[PFIM, RER] = compute_PFIM_RER(data, dname);

% plot 3D PFIM
figure;
plot_PFIM_Schlogl(PFIM, data);

% % plot various RERs (perturbation vector must have specific structure)
% figure;
% plot_RER(RER, PFIM, data);


