function c = update_rates(c, data, k_rea)
%
% Update the rates of all reactions that involves the species of the fired
% k-th reaction.
%
%  ---- INPUT PARAMETERS ----
%   c: rates vector, [Mx1]
%   data: data structure array
%
%   data.M: number of reactions, [1x1]
%   data.X: current population of the system, [Nx1]
%   data.con: value of reaction constants, [Kx1]
%   data.stoichio: stoichiometric matrix, [Mx4]
%   data.cm_rea: connectivity matrix for the reactions, [Mx4]
%   data.cm_spe: connectivity matrix for the species, [MxK+1]
%
%   k_rea: which reaction was fired, [1x1]
%
% ---- OUTPUT PARAMETERS ----
%   c: vector with the updated rates, [Mx1]
%
% (c) Math & Stat, Umass, Amherst, 2014


% the k-th flag is false if the k-th reaction rate is already updated.
BOOL = ones(data.M , 1);

% loop over all species in 'k_rea' reaction
for i=1:4
    
    spe_i = data.cm_rea(k_rea, i);
    
    % if i-th species is not zero
    if spe_i ~= 0
    
        % loop over all reactions involving 'spe_i'
        for k = 1 : data.cm_spe(spe_i, 1)
            
            reaction = data.cm_spe(spe_i , k+1) ;    
            
            % if not already computed then compute rate
            if BOOL(reaction)
                c(reaction) =  reaction_rate(data, reaction);
                BOOL(reaction) = 0;
            end

        end % End 'loop over all reactions involving 'spe_i''
         
    end % End if
    
end % End 'loop over all species in 'k_rea' reaction'

